pub struct NetAddress {
pub address: Address,
pub mask: NetMask,
}Expand description
Address of a network, i.e. an Address in combination with a NetMask.
Fields
address: Addressmask: NetMaskTrait Implementations
Sourceimpl Bind<NetAddress> for ActorContext
impl Bind<NetAddress> for ActorContext
async fn bind( &mut self, args: BindArgs<NetAddress>, ) -> Result<(), ErrorOf<BindErrorKind>>
Sourceimpl Clone for NetAddress
impl Clone for NetAddress
Sourcefn clone(&self) -> NetAddress
fn clone(&self) -> NetAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NetAddress
Sourceimpl Debug for NetAddress
impl Debug for NetAddress
Sourceimpl<'de> Deserialize<'de> for NetAddress
impl<'de> Deserialize<'de> for NetAddress
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<NetAddress, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<NetAddress, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for NetAddress
impl Display for NetAddress
impl Eq for NetAddress
Sourceimpl From<Address> for NetAddress
impl From<Address> for NetAddress
Sourcefn from(address: Address) -> NetAddress
fn from(address: Address) -> NetAddress
Converts to this type from the input type.
Sourceimpl From<AddressRange> for NetAddress
impl From<AddressRange> for NetAddress
Sourcefn from(range: AddressRange) -> NetAddress
fn from(range: AddressRange) -> NetAddress
Converts to this type from the input type.
Sourceimpl From<NetAddress> for AddressRange
impl From<NetAddress> for AddressRange
Sourcefn from(net: NetAddress) -> AddressRange
fn from(net: NetAddress) -> AddressRange
Converts to this type from the input type.
Sourceimpl FromStr for NetAddress
impl FromStr for NetAddress
Sourcetype Err = NetAddressParseError
type Err = NetAddressParseError
The associated error which can be returned from parsing.
Sourcefn from_str(s: &str) -> Result<NetAddress, <NetAddress as FromStr>::Err>
fn from_str(s: &str) -> Result<NetAddress, <NetAddress as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for NetAddress
impl Hash for NetAddress
impl Message for NetAddress
Sourceimpl Ord for NetAddress
impl Ord for NetAddress
Sourcefn cmp(&self, other: &NetAddress) -> Ordering
fn cmp(&self, other: &NetAddress) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NetAddress
impl PartialEq for NetAddress
Sourcefn eq(&self, other: &NetAddress) -> bool
fn eq(&self, other: &NetAddress) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for NetAddress
impl PartialOrd for NetAddress
Sourceimpl Serialize for NetAddress
impl Serialize for NetAddress
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for NetAddress